/*******************************************************************************
 * Copyright (c) 2010 BSI Business Systems Integration AG.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     BSI Business Systems Integration AG - initial API and implementation
 ******************************************************************************/
package org.eclipse.quarztest.server;

import org.eclipse.equinox.app.IApplication;
import org.eclipse.equinox.app.IApplicationContext;
import org.eclipse.scout.commons.logger.IScoutLogger;
import org.eclipse.scout.commons.logger.ScoutLogManager;
import org.quartz.Job;
import org.quartz.JobDetail;
import org.quartz.JobExecutionContext;
import org.quartz.JobExecutionException;
import org.quartz.Scheduler;
import org.quartz.SchedulerException;
import org.quartz.Trigger;
import org.quartz.impl.JobDetailImpl;
import org.quartz.impl.StdSchedulerFactory;
import org.quartz.impl.triggers.SimpleTriggerImpl;

/**
 * Dummy application in order to manage server side product configurations in *.product files.
 * A typical config.ini for such a product has (among others) the following properties:
 * osgi.clean=true
 * osgi.console=
 * eclipse.consoleLog=true
 * org.eclipse.equinox.http.jetty.http.port=8080
 * org.eclipse.equinox.http.jetty.context.path=/quarztest
 * osgi.bundles=org.eclipse.equinox.common@2:start, org.eclipse.update.configurator@start,
 * org.eclipse.equinox.http.jetty@start, org.eclipse.equinox.http.registry@start, org.eclipse.core.runtime@start
 * osgi.bundles.defaultStartLevel=4
 * osgi.noShutdown=true
 * eclipse.ignoreApp=false
 * eclipse.product=org.eclipse.quarztest.server.product
 */
public class ServerApplication implements IApplication {
  private static IScoutLogger logger = ScoutLogManager.getLogger(ServerApplication.class);
  private Scheduler scheduler;

  public Object start(IApplicationContext context) throws Exception {
    //start the scheduler

    try {
      // Grab the Scheduler instance from the Factory 
      scheduler = StdSchedulerFactory.getDefaultScheduler();

      // and start it off
      scheduler.start();
      // Define job instance
      JobDetail job = new JobDetailImpl("job1", "group1", P_Job.class);

      // Define a Trigger that will fire "now"
      Trigger trigger = new SimpleTriggerImpl("trigger1", "group1", 10, 2000l);//new Date());

      // Schedule the job with the trigger
      scheduler.scheduleJob(job, trigger);
//      scheduler.shutdown();

    }
    catch (SchedulerException se) {
      se.printStackTrace();
    }
    logger.info("quarztest server initialized");
    return EXIT_OK;
  }

  public void stop() {
    try {
      scheduler.shutdown();
    }
    catch (SchedulerException e) {
      // TODO Auto-generated catch block
      e.printStackTrace();
    }
  }

  public static class P_Job implements Job {
    public void execute(JobExecutionContext arg0) throws JobExecutionException {
      System.out.println("Doit");
    }
  }
}
